==> blue_flie-4.44.1.tar.gz: blue_flie-4.44.1/blue_flie/help/gazebo.py <==
from typing import List

from blue_options.terminal import show_usage, xtra


def help_browse(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra(
        "dryrun,~download,filename=<filename.sdf>,~gif,install,~pictures,~upload",
        mono=mono,
    )

    return show_usage(
        [
            "@gazebo",
            "browse",
            f"[{options}]",
            "[-|<object-name>]",
        ],
        "browse <object-name> in gazebo.",
        mono=mono,
    )


def help_ingest(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("dryrun,~upload", mono=mono)

    return show_usage(
        [
            "@gazebo",
            "ingest",
            f"[{options}]",
            "<example-name>",
            "[-|<object-name>]",
        ],
        "ingest <example-name> -> <object-name>.",
        mono=mono,
    )


def help_ingest_list(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@gazebo",
            "ingest",
            "list",
        ],
        "list gazebo examples.",
        mono=mono,
    )


def help_install(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("dryrun", mono=mono)

    return show_usage(
        [
            "@gazebo",
            "install",
            f"[{options}]",
        ],
        "install gazebo.",
        mono=mono,
    )


help_functions = {
    "browse": help_browse,
    "ingest": {
        "": help_ingest,
        "list": help_ingest_list,
    },
    "install": help_install,
}

==> blue_flie-4.53.1.tar.gz: blue_flie-4.53.1/blue_flie/help/gazebo.py <==
from typing import List

from blue_options.terminal import show_usage, xtra

example_details = {"examples: https://github.com/gazebosim/gz-sim/examples/worlds/": []}


def browse_options(
    mono: bool,
    cascade: bool = False,
):
    return "".join(
        [
            xtra(
                "dryrun,",
                mono=mono,
            ),
            (
                ""
                if cascade
                else xtra(
                    "~download,",
                    mono=mono,
                )
            ),
            xtra(
                "filename=<filename.sdf>,~gif,install,~pictures,~upload",
                mono=mono,
            ),
        ]
    )


def help_browse(
    tokens: List[str],
    mono: bool,
) -> str:

    return show_usage(
        [
            "@gazebo",
            "browse",
            f"[{browse_options(mono=mono)}]",
            "[-|<object-name>]",
        ],
        "browse <object-name> in gazebo.",
        mono=mono,
    )


def help_ingest(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("dryrun,~upload", mono=mono)

    return show_usage(
        [
            "@gazebo",
            "ingest",
            f"[{options}]",
            "<example-name>",
            "[-|<object-name>]",
            "[browse,{}]".format(
                browse_options(
                    mono=mono,
                    cascade=True,
                )
            ),
        ],
        "ingest <example-name> -> <object-name>.",
        example_details,
        mono=mono,
    )


def help_ingest_list(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@gazebo",
            "ingest",
            "list",
        ],
        "list gazebo examples.",
        example_details,
        mono=mono,
    )


def help_install(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("dryrun", mono=mono)

    return show_usage(
        [
            "@gazebo",
            "install",
            f"[{options}]",
        ],
        "install gazebo.",
        mono=mono,
    )


help_functions = {
    "browse": help_browse,
    "ingest": {
        "": help_ingest,
        "list": help_ingest_list,
    },
    "install": help_install,
}
